# SDFEst
SDFEst is a package for pose, scale, and shape estimation using discretized signed distance fields. It includes and combines three main components (generative model, discriminative initialization, and differentiable renderer) to enable pose and shape estimation in an analysis-by-synthesis framework.

Check the [GitHub page](https://github.com/roym899/sdfest#sdfest) for usage instructions.
